/**
 * ----------------------------------------------------------------------------
 * "THE BEER-WARE LICENSE":
 * The Cocoakit author wrote this file. As long as you retain this notice you
 * can do whatever you want with this stuff. If we meet some day, and you think
 * this stuff is worth it, you can buy me a beer in return or, drink a beer in 
 * my honor.
 * ----------------------------------------------------------------------------
 */

#import "CKNibLoader.h"

#pragma mark -

/**
 * CKNibLoader private category
 */
@interface CKNibLoader ()

/**
 * Returns the singleton only instance
 *
 * @return Singleton only instance
 * @private
 */
+ (CKNibLoader *)getInstance;

/**
 * Creates and returns an autoreleased UIView constructed from a NIB file
 *
 * @param aNibFile The NIB file to construct the view from
 * @return The autoreleased UIView constructed from a NIB file
 * @private
 */
- (UIView *)loadViewFromNIBFile:(NSString *)aNibFile;

@end

@implementation CKNibLoader

#pragma mark -
#pragma mark Properties

@synthesize auxView = auxView_;

#pragma mark -
#pragma mark Static attributes

/**
 * ViewNibLoader singleton only instance
 */
static CKNibLoader *viewNibLoaderInstance_ = nil;

#pragma mark -
#pragma mark Memory management

/**
 * Deallocates the memory occupied by the receiver.
 */
- (void)dealloc {
    
    [auxView_ release];
    auxView_ = nil;
    
    [super dealloc];
    
}

#pragma mark -
#pragma mark Singleton methods

/**
 * Allocates the singleton instance, in case it is not already allocated
 *
 * @param zone The memory zone to allocate the singleton in
 * @return The newly allocated singleton instance, or nil if singleton was already allocated
 */
+ (id)allocWithZone:(NSZone *)zone {
    
    @synchronized([CKNibLoader class]) {
        
        if (viewNibLoaderInstance_ == nil) {
            
            viewNibLoaderInstance_ = [super allocWithZone:zone];
            
            return viewNibLoaderInstance_;
            
        }
        
    }
    
    return nil;
    
}

#pragma mark -
#pragma mark Singleton selectors

/*
 * Returns the singleton only instance
 */
+ (CKNibLoader *)getInstance {
    
    if (viewNibLoaderInstance_ == nil) {
        
        @synchronized([CKNibLoader class]) {
            
            if (viewNibLoaderInstance_ == nil) {
                
                viewNibLoaderInstance_ = [[CKNibLoader alloc] init];
                
            }
            
        }
        
    }
    
    return viewNibLoaderInstance_;
    
}

#pragma mark -
#pragma mark UIView construction

/*
 * Creates and returns an autoreleased UIView constructed from a NIB file
 */
- (UIView *)loadViewFromNIBFile:(NSString *)aNibFile {
    
    [[NSBundle mainBundle] loadNibNamed:aNibFile owner:self options:nil];
    
    UIView *result = auxView_;
    auxView_ = nil;
    
    return result;
    
}

/*
 * Creates the autoreleased view from NIB file.
 */
+ (UIView *)loadViewFromNIBFile:(NSString *)nibFile {
  
    CKNibLoader *viewNibLoader = [CKNibLoader getInstance];
    
    return [viewNibLoader loadViewFromNIBFile:nibFile];
    
}

@end
