/**
 * ----------------------------------------------------------------------------
 * "THE BEER-WARE LICENSE":
 * The Cocoakit author wrote this file. As long as you retain this notice you
 * can do whatever you want with this stuff. If we meet some day, and you think
 * this stuff is worth it, you can buy me a beer in return or, drink a beer in 
 * my honor.
 * ----------------------------------------------------------------------------
 */

#import <UIKit/UIKit.h>

@protocol CKSwitchCellDelegate

/**
 * Class tell to delegate to indicate the selected switch.
 *
 * @param index: The index of cell.
 * @param isON: Flag to know if switch is ON or NO.
 */
- (void)didSelectedSwitchWithIndex:(NSUInteger)index enable:(BOOL)isON;

@end

/**
 * The UITableViewCell that customized with switch.
 *
 * @author <a href="mailto:ivan.palmergarcia@gmail.com">Ivan Palmer</a>
 */
@interface CKSwitchCell : UITableViewCell {
@private
    
#pragma Visual
    
    /**
     * The text label.
     */
    UILabel *textLabel_;
    
    /**
     * The switch view.
     */
    UISwitch *switchView_;
    
#pragma Logic
    
    NSUInteger index_;
    
    /**
     * The delegate.
     */
    id<CKSwitchCellDelegate> delegate_;
    
}

/**
 * Provides read-write access to textLabel. Connected to Interface Builder.
 */
@property (nonatomic, readwrite, retain) IBOutlet UILabel *textLabel;

/**
 * Provides read-write access to switchView. Connected to Interface Builder.
 */
@property (nonatomic, readwrite, retain) IBOutlet UISwitch *switchView;

/**
 * Provides read-write access to index.
 */
@property (nonatomic, readwrite, assign) NSUInteger index;

/**
 * Provides read-write access to delegate.
 */
@property (nonatomic, readwrite, assign) id<CKSwitchCellDelegate> delegate;

/**
 * Create and return an autoreleased CKSwitchCell contructed from NIB file.
 *
 * @return An autoreleased CKSwitchCell constructed from NIB file.
 */
+ (CKSwitchCell *)ckSwitchCell;

/**
 * Return the cell identifier.
 *
 * @return The cell identifier.
 */
+ (NSString *)cellIdentifier;

/**
 * Return the cell height.
 *
 * @return The cell height.
 */
+ (CGFloat)cellHeight;

/**
 * The switch is changed.
 */
- (IBAction)switchChanged:(id)sender;

@end
