/**
 * ----------------------------------------------------------------------------
 * "THE BEER-WARE LICENSE":
 * The Cocoakit author wrote this file. As long as you retain this notice you
 * can do whatever you want with this stuff. If we meet some day, and you think
 * this stuff is worth it, you can buy me a beer in return or, drink a beer in 
 * my honor.
 * ----------------------------------------------------------------------------
 */

#import "CKSwitchCell.h"

#import "CKNibLoader.h"

/**
 * Defines a NIB file name.
 */
#define NIB_FILE_NAME                                                           @"CKSwitchCell"

/**
 * Defines the cell identifier.
 */
#define CELL_IDENTIFIER                                                         @"CKSwitchCell"

/**
 * Defines the cell height.
 */
#define CELL_HEIGHT                                                             45.0f

@implementation CKSwitchCell

#pragma mark -
#pragma mark Properties

@synthesize textLabel = textLabel_;
@synthesize switchView = switchView_;
@synthesize index = index_;
@synthesize delegate = delegate_;

#pragma mark -
#pragma mark Memory management

/**
 * Deallocates the memory occupied by the receiver.
 */
- (void)dealloc {
    
    [textLabel_ release];
    textLabel_ = nil;
    
    [switchView_ release];
    switchView_ = nil;
    
    index_ = -1;
    
    delegate_ = nil;
    
    [super dealloc];
    
}

#pragma mark -
#pragma mark Instances initialization

/*
 * Create and return an autoreleased CKViewController contructed from NIB file.
 */
+ (CKSwitchCell *)ckSwitchCell {
    
    return (CKSwitchCell *)[CKNibLoader loadViewFromNIBFile:NIB_FILE_NAME];
    
}

#pragma mark -
#pragma mark CKSwitchCell selectors

/**
 * Return the cell identifier.
 *
 * @return The cell identifier.
 */
+ (NSString *)cellIdentifier {
    
    return CELL_IDENTIFIER;
    
}

/**
 * Return the cell height.
 *
 * @return The cell height.
 */
+ (CGFloat)cellHeight {
    
    return CELL_HEIGHT;
    
}

/*
 * The switch is changed.
 */
- (IBAction)switchChanged:(id)sender {
    
    UISwitch *sw = (UISwitch *)sender;
    
    [delegate_ didSelectedSwitchWithIndex:index_ enable:[sw isOn]];
    
}

/**
 * Set the index_ value to another value.
 *
 * @param index: Another value to index_.
 */
- (void)setIndex:(NSUInteger)index {
    
    index_ = index;
    
    [switchView_ setOn:NO];
    
}

@end
